==> BCTLSNetwork_4_2025-12-21_12.46.21.jar: ca/tecreations/apps/App.java <==
package ca.tecreations.apps;

import ca.tecreations.*;
import ca.tecreations.apps._gui.EntriesPanel;
import ca.tecreations.components.*;

import java.awt.event.*;
import java.awt.dnd.DragSource;
import javax.swing.event.*;
/**
 *
 * @author Tim
 */
public abstract class App extends TFrame implements ActionListener, KeyListener, MouseListener,
        MouseMotionListener, MouseWheelListener, DocumentListener {
    public static TextFile log = null;
    public static String PROPS_EXTENSION = ".properties";
    public static String appName;
    DragSource ds = null;
    
    public App(String propsPath,String tag) {
        super(propsPath,tag);
        appName = tag;
    }
    
    public void actionPerformed(ActionEvent e) {}

    public String getAppName() {
        return appName;
    }
    
    public void itemStateChanged(ItemEvent e) {}
    public void keyPressed(KeyEvent e) {}
    public void keyReleased(KeyEvent e) {}
    public void keyTyped(KeyEvent e) {}
    public void mouseClicked(MouseEvent e) {}
    public void mouseDragged(MouseEvent e) {} 
    public void mouseEntered(MouseEvent e) {} 
    public void mouseExited(MouseEvent e) {} 
    public void mouseMoved(MouseEvent e) {}
    public void mousePressed(MouseEvent e) {} 
    public void mouseReleased(MouseEvent e) {}
    public void mouseWheelMoved(MouseWheelEvent e) {} 

    public void changedUpdate(DocumentEvent e) {}
    public void insertUpdate(DocumentEvent e) {}
    public void removeUpdate(DocumentEvent e) {}
    
    public void refreshLast() {}
    
    public abstract void deleteHost(String name);
    
    public void setDragSource(DragSource ds) {
        this.ds = ds;
    }
    
}

==> BCTLSNetwork_10_2025-11-29_18.21.01.jar: ca/tecreations/apps/App.java <==
package ca.tecreations.apps;

import ca.tecreations.*;
import ca.tecreations.apps._gui.EntriesPanel;
import ca.tecreations.components.*;

import java.awt.event.*;
import java.awt.dnd.DragSource;
import javax.swing.event.*;
/**
 *
 * @author Tim
 */
public class App extends TFrame implements ActionListener, KeyListener, MouseListener,
        MouseMotionListener, MouseWheelListener, DocumentListener {
    public static TextFile log = null;
    public static String PROPS_EXTENSION = ".properties";
    
    DragSource ds = null;
    
    public App(String propsPath,String tag) {
        super(propsPath,tag);
    }
    
    public static void main(String[] args) {
        App instance = new App(ProjectPath.getTecPropsPath() + App.class.getSimpleName(),App.class.getSimpleName());
    }
    
    public void actionPerformed(ActionEvent e) {}

    public void itemStateChanged(ItemEvent e) {}
    public void keyPressed(KeyEvent e) {}
    public void keyReleased(KeyEvent e) {}
    public void keyTyped(KeyEvent e) {}
    public void mouseClicked(MouseEvent e) {}
    public void mouseDragged(MouseEvent e) {} 
    public void mouseEntered(MouseEvent e) {} 
    public void mouseExited(MouseEvent e) {} 
    public void mouseMoved(MouseEvent e) {}
    public void mousePressed(MouseEvent e) {} 
    public void mouseReleased(MouseEvent e) {}
    public void mouseWheelMoved(MouseWheelEvent e) {} 

    public void changedUpdate(DocumentEvent e) {}
    public void insertUpdate(DocumentEvent e) {}
    public void removeUpdate(DocumentEvent e) {}
    
    public void refreshLast() {}
    
    public void setDragSource(DragSource ds) {
        this.ds = ds;
    }
    
}
